import { __decorate, __extends, __values } from 'tslib';
import { EventEmitter, Injectable, Input, Output, Component, NgModule } from '@angular/core';
import { CommonsDrawerService, ECommonsDrawerDirection, NgxWebAppCommonsMobileModule } from 'ngx-webappcommons-mobile';
import { CommonsComponent } from 'ngx-angularcommons-core';
import { CommonModule } from '@angular/common';
import { NgxWebAppCommonsCoreModule } from 'ngx-webappcommons-core';

var FULL_KEYBOARD = {
    default: 'lower',
    sets: {
        lower: { label: 'a-z', keys: [
                [
                    { cancel: true, icon: 'cancel' },
                    { character: '1' },
                    { character: '2' },
                    { character: '3' },
                    { character: '4' },
                    { character: '5' },
                    { character: '6' },
                    { character: '7' },
                    { character: '8' },
                    { character: '9' },
                    { character: '0' },
                    { backspace: true, icon: 'backspace' }
                ], [
                    null,
                    { character: 'q' },
                    { character: 'w' },
                    { character: 'e' },
                    { character: 'r' },
                    { character: 't' },
                    { character: 'y' },
                    { character: 'u' },
                    { character: 'i' },
                    { character: 'o' },
                    { character: 'p' },
                    { ok: true, icon: 'check_circle' }
                ], [
                    { set: 'upper', span: 2 },
                    { character: 'a' },
                    { character: 's' },
                    { character: 'd' },
                    { character: 'f' },
                    { character: 'g' },
                    { character: 'h' },
                    { character: 'j' },
                    { character: 'k' },
                    { character: 'l' }
                ], [
                    { set: 'symbols', span: 2 },
                    { character: 'z' },
                    { character: 'x' },
                    { character: 'c' },
                    { character: 'v' },
                    { character: 'b' },
                    { character: 'n' },
                    { character: 'm' }
                ], [
                    null,
                    null,
                    null,
                    null,
                    { space: true, span: 4 }
                ]
            ] },
        upper: { label: 'A-Z', keys: [
                [
                    { cancel: true, icon: 'cancel' },
                    { character: '1' },
                    { character: '2' },
                    { character: '3' },
                    { character: '4' },
                    { character: '5' },
                    { character: '6' },
                    { character: '7' },
                    { character: '8' },
                    { character: '9' },
                    { character: '0' },
                    { backspace: true, icon: 'backspace' }
                ], [
                    null,
                    { character: 'Q' },
                    { character: 'W' },
                    { character: 'E' },
                    { character: 'R' },
                    { character: 'T' },
                    { character: 'Y' },
                    { character: 'U' },
                    { character: 'I' },
                    { character: 'O' },
                    { character: 'P' },
                    { ok: true, icon: 'check_circle' }
                ], [
                    { set: 'lower', span: 2 },
                    { character: 'A' },
                    { character: 'S' },
                    { character: 'D' },
                    { character: 'F' },
                    { character: 'G' },
                    { character: 'H' },
                    { character: 'J' },
                    { character: 'K' },
                    { character: 'L' }
                ], [
                    { set: 'symbols', span: 2 },
                    { character: 'Z' },
                    { character: 'X' },
                    { character: 'C' },
                    { character: 'V' },
                    { character: 'B' },
                    { character: 'N' },
                    { character: 'M' }
                ], [
                    null,
                    null,
                    null,
                    null,
                    { space: true, span: 4 }
                ]
            ] },
        symbols: { label: '@#*', keys: [
                [
                    { cancel: true, icon: 'cancel' },
                    { character: '!' },
                    { character: '"' },
                    { character: '£' },
                    { character: '$' },
                    { character: '%' },
                    { character: '^' },
                    { character: '&' },
                    { character: '*' },
                    { character: '(' },
                    { character: ')' },
                    { backspace: true, icon: 'backspace' }
                ], [
                    null,
                    { character: '-' },
                    { character: '=' },
                    { character: '_' },
                    { character: '+' },
                    { character: '[' },
                    { character: ']' },
                    { character: '{' },
                    { character: '}' },
                    { character: ';' },
                    { character: '\'' },
                    { ok: true, icon: 'check_circle' }
                ], [
                    null,
                    null,
                    { character: '#' },
                    { character: ':' },
                    { character: '@' },
                    { character: '~' },
                    { character: ',' },
                    { character: '.' },
                    { character: '/' },
                    { character: '<' },
                    { character: '>' }
                ], [
                    { set: 'lower', span: 2 },
                    { character: '?' },
                    { character: '`' },
                    { character: '¬' },
                    { character: '|' }
                ], [
                    null,
                    null,
                    null,
                    null,
                    { space: true, span: 4 }
                ]
            ] }
    }
};
var SIMPLE_KEYBOARD = {
    default: 'alphanumeric',
    sets: {
        alphanumeric: { label: 'AZ09', keys: [
                [
                    { character: '1' },
                    { character: '2' },
                    { character: '3' },
                    { character: '4' },
                    { character: '5' },
                    { character: '6' },
                    { character: '7' },
                    { character: '8' },
                    { character: '9' },
                    { character: '0' }
                ], [
                    { character: 'Q' },
                    { character: 'W' },
                    { character: 'E' },
                    { character: 'R' },
                    { character: 'T' },
                    { character: 'Y' },
                    { character: 'U' },
                    { character: 'I' },
                    { character: 'O' },
                    { character: 'P' }
                ], [
                    { character: 'A' },
                    { character: 'S' },
                    { character: 'D' },
                    { character: 'F' },
                    { character: 'G' },
                    { character: 'H' },
                    { character: 'J' },
                    { character: 'K' },
                    { character: 'L' }
                ], [
                    null,
                    { character: 'Z' },
                    { character: 'X' },
                    { character: 'C' },
                    { character: 'V' },
                    { character: 'B' },
                    { character: 'N' },
                    { character: 'M' }
                ], [
                    { set: 'symbols', span: 2 },
                    { space: true, span: 4 },
                    { backspace: true, icon: 'backspace' },
                    null,
                    { ok: true, icon: 'check_circle' },
                    { cancel: true, icon: 'cancel' }
                ]
            ] },
        symbols: { label: '@#*', keys: [
                [
                    { character: '!' },
                    { character: '"' },
                    { character: '£' },
                    { character: '$' },
                    { character: '%' },
                    { character: '^' },
                    { character: '&' },
                    { character: '*' },
                    { character: '(' },
                    { character: ')' }
                ], [
                    { character: '-' },
                    { character: '_' },
                    { character: '+' },
                    { character: '=' },
                    { character: '[' },
                    { character: ']' },
                    { character: '{' },
                    { character: '}' }
                ], [
                    { character: ';' },
                    { character: ':' },
                    { character: '\'' },
                    { character: '@' },
                    { character: '#' },
                    { character: '~' }
                ], [
                    { character: ',' },
                    { character: '.' },
                    { character: '<' },
                    { character: '>' },
                    { character: '/' },
                    { character: '?' }
                ], [
                    { set: 'alphanumeric', span: 2 },
                    { space: true, span: 4 },
                    { backspace: true, icon: 'backspace' },
                    null,
                    { ok: true, icon: 'check_circle' },
                    { cancel: true, icon: 'cancel' }
                ]
            ] }
    }
};
var LOGIN_PIN_KEYBOARD = {
    default: 'numeric',
    sets: {
        numeric: { label: '', keys: [
                [
                    { character: '1' },
                    { character: '2' },
                    { character: '3' }
                ], [
                    { character: '4' },
                    { character: '5' },
                    { character: '6' }
                ], [
                    { character: '7' },
                    { character: '8' },
                    { character: '9' }
                ], [
                    { backspace: true, icon: 'backspace' },
                    { character: '0' },
                    { ok: true, icon: 'check_circle' }
                ]
            ] }
    }
};

var CommonsEditorService = /** @class */ (function () {
    function CommonsEditorService(drawerService) {
        this.drawerService = drawerService;
        this.showEmitter = new EventEmitter(true);
        this.hideEmitter = new EventEmitter(true);
    }
    CommonsEditorService.prototype.edit = function (value, settings, ok, cancel) {
        var _this = this;
        this.showEmitter.emit({
            value: value,
            settings: settings,
            ok: function (v) {
                _this.hide();
                ok(v);
            },
            cancel: function () {
                _this.hide();
                if (cancel)
                    cancel();
            }
        });
        this.drawerService.show('_editor');
    };
    CommonsEditorService.prototype.hide = function () {
        var _this = this;
        this.drawerService.hide('_editor');
        setTimeout(function () { _this.hideEmitter.emit(); }, 250); // wait for the 200ms animation to finish
    };
    CommonsEditorService.prototype.showObservable = function () {
        return this.showEmitter;
    };
    CommonsEditorService.prototype.hideObservable = function () {
        return this.hideEmitter;
    };
    CommonsEditorService.ctorParameters = function () { return [
        { type: CommonsDrawerService }
    ]; };
    CommonsEditorService = __decorate([
        Injectable()
    ], CommonsEditorService);
    return CommonsEditorService;
}());

var CommonsKeyboardKeyComponent = /** @class */ (function (_super) {
    __extends(CommonsKeyboardKeyComponent, _super);
    function CommonsKeyboardKeyComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.setLabels = {};
        _this.disabled = false;
        _this.disableThemeInvert = false;
        _this.onCharacter = new EventEmitter(true);
        _this.onSpace = new EventEmitter(true);
        _this.onOk = new EventEmitter(true);
        _this.onCancel = new EventEmitter(true);
        _this.onBackspace = new EventEmitter(true);
        _this.onSet = new EventEmitter(true);
        return _this;
    }
    CommonsKeyboardKeyComponent.prototype.doClick = function () {
        if (this.key.cancel) {
            this.onCancel.emit();
            return;
        }
        if (this.key.space) {
            this.onSpace.emit();
            return;
        }
        if (this.key.ok) {
            this.onOk.emit();
            return;
        }
        if (this.key.backspace) {
            this.onBackspace.emit();
            return;
        }
        if (this.key.set !== undefined) {
            this.onSet.emit(this.key.set);
            return;
        }
        if (this.key.character !== undefined) {
            this.onCharacter.emit(this.key.character);
            return;
        }
    };
    __decorate([
        Input()
    ], CommonsKeyboardKeyComponent.prototype, "key", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardKeyComponent.prototype, "setLabels", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardKeyComponent.prototype, "disabled", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardKeyComponent.prototype, "disableThemeInvert", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardKeyComponent.prototype, "maxColumns", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardKeyComponent.prototype, "onCharacter", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardKeyComponent.prototype, "onSpace", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardKeyComponent.prototype, "onOk", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardKeyComponent.prototype, "onCancel", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardKeyComponent.prototype, "onBackspace", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardKeyComponent.prototype, "onSet", void 0);
    CommonsKeyboardKeyComponent = __decorate([
        Component({
            selector: 'commons-keyboard-key',
            template: "<button\n\t\t[class]=\"'keyboard columns-' + this.maxColumns\"\n\t\t[class.span2]=\"this.key.span === 2\"\n\t\t[class.span3]=\"this.key.span === 3\"\n\t\t[class.span4]=\"this.key.span === 4\"\n\t\t[class.space]=\"this.key.space\"\n\t\t[class.set]=\"this.key.set\"\n\t\t[class.secondary]=\"this.key.ok\"\n\t\t[class.disableThemeInvert]=\"this.disableThemeInvert\"\n\t\t[disabled]=\"this.disabled\"\n\t\t(click)=\"this.doClick()\"\n>\n\t<i *ngIf=\"this.key.icon\" class=\"material-icons\">{{this.key.icon}}</i>\n\t<ng-container *ngIf=\"this.key.set\">{{this.setLabels[this.key.set]}}</ng-container>\n\t<ng-container *ngIf=\"this.key.character !== undefined\">{{this.key.character}}</ng-container>\n</button>\n",
            styles: ["@charset 'utf8';button{-webkit-appearance:none;-moz-appearance:none;appearance:none;font-family:Roboto;font-size:16px;line-height:16px;font-weight:500;box-sizing:border-box;padding:0;width:100%;height:43px;min-width:0;overflow:hidden;border:0;border-radius:2px;margin:0;outline:0}button.space{margin:10px 0;height:23px}button.set{padding-top:1px;font-size:14px;font-weight:500}:host-context(body.webappcommons-theme-blue) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-blue) button.secondary{color:#ffc107}:host-context(body.webappcommons-theme-blue) button:active{background-color:#ffc107;color:#000}:host-context(body.webappcommons-theme-blue) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-blue) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-blue) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-blue) button.space:active{background:#ffc107}:host-context(body.webappcommons-theme-darkred) button{background-color:transparent;color:#b8b8b8}:host-context(body.webappcommons-theme-darkred) button.secondary{color:#ffeb3b}:host-context(body.webappcommons-theme-darkred) button:active{background-color:#ffeb3b;color:#000}:host-context(body.webappcommons-theme-darkred) button:disabled{color:#4e4e4e}:host-context(body.webappcommons-theme-darkred) button:disabled.disableThemeInvert{color:rgba(114,114,114,.75)}:host-context(body.webappcommons-theme-darkred) button.space{background:#505050}:host-context(body.webappcommons-theme-darkred) button.space:active{background:#ffeb3b}:host-context(body.webappcommons-theme-hotpink) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-hotpink) button.secondary{color:#9debef}:host-context(body.webappcommons-theme-hotpink) button:active{background-color:#9debef;color:#000}:host-context(body.webappcommons-theme-hotpink) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-hotpink) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-hotpink) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-hotpink) button.space:active{background:#9debef}:host-context(body.webappcommons-theme-marine) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-marine) button.secondary{color:#99d1dd}:host-context(body.webappcommons-theme-marine) button:active{background-color:#99d1dd;color:#000}:host-context(body.webappcommons-theme-marine) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-marine) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-marine) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-marine) button.space:active{background:#99d1dd}:host-context(body.webappcommons-theme-muted) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-muted) button.secondary{color:#fdd835}:host-context(body.webappcommons-theme-muted) button:active{background-color:#fdd835;color:#000}:host-context(body.webappcommons-theme-muted) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-muted) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-muted) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-muted) button.space:active{background:#fdd835}:host-context(body.webappcommons-theme-night) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-night) button.secondary{color:#e7c385}:host-context(body.webappcommons-theme-night) button:active{background-color:#e7c385;color:#000}:host-context(body.webappcommons-theme-night) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-night) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-night) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-night) button.space:active{background:#e7c385}:host-context(body.webappcommons-theme-patrolred) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-patrolred) button.secondary{color:#90a4ae}:host-context(body.webappcommons-theme-patrolred) button:active{background-color:#90a4ae;color:#fff}:host-context(body.webappcommons-theme-patrolred) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-patrolred) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-patrolred) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-patrolred) button.space:active{background:#90a4ae}:host-context(body.webappcommons-theme-purple) button{background-color:transparent;color:#333}:host-context(body.webappcommons-theme-purple) button.secondary{color:#fc3}:host-context(body.webappcommons-theme-purple) button:active{background-color:#fc3;color:#000}:host-context(body.webappcommons-theme-purple) button:disabled{color:#c2c2c2}:host-context(body.webappcommons-theme-purple) button:disabled.disableThemeInvert{color:rgba(145,145,145,.75)}:host-context(body.webappcommons-theme-purple) button.space{background:#bfbfbf}:host-context(body.webappcommons-theme-purple) button.space:active{background:#fc3}"]
        })
    ], CommonsKeyboardKeyComponent);
    return CommonsKeyboardKeyComponent;
}(CommonsComponent));

var CommonsKeyboardComponent = /** @class */ (function (_super) {
    __extends(CommonsKeyboardComponent, _super);
    function CommonsKeyboardComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.disableOk = false;
        _this.disableCancel = false;
        _this.disableBackspace = false;
        _this.disableCharacters = false;
        _this.disableThemeInvert = false;
        _this.onCharacter = new EventEmitter(true);
        _this.onOk = new EventEmitter(true);
        _this.onCancel = new EventEmitter(true);
        _this.onBackspace = new EventEmitter(true);
        _this.set = undefined;
        _this.maxColumns = 0;
        return _this;
    }
    CommonsKeyboardComponent.prototype.ngOnInit = function () {
        var e_1, _a, e_2, _b, e_3, _c;
        _super.prototype.ngOnInit.call(this);
        this.set = this.keyboard.default;
        this.maxColumns = 0;
        try {
            for (var _d = __values(Object.keys(this.keyboard.sets)), _e = _d.next(); !_e.done; _e = _d.next()) {
                var set = _e.value;
                try {
                    for (var _f = (e_2 = void 0, __values(this.keyboard.sets[set].keys)), _g = _f.next(); !_g.done; _g = _f.next()) {
                        var row = _g.value;
                        var max = 0;
                        try {
                            for (var row_1 = (e_3 = void 0, __values(row)), row_1_1 = row_1.next(); !row_1_1.done; row_1_1 = row_1.next()) {
                                var key = row_1_1.value;
                                if (key && key.span)
                                    max += key.span;
                                else
                                    max++;
                            }
                        }
                        catch (e_3_1) { e_3 = { error: e_3_1 }; }
                        finally {
                            try {
                                if (row_1_1 && !row_1_1.done && (_c = row_1.return)) _c.call(row_1);
                            }
                            finally { if (e_3) throw e_3.error; }
                        }
                        this.maxColumns = Math.max(this.maxColumns, max);
                    }
                }
                catch (e_2_1) { e_2 = { error: e_2_1 }; }
                finally {
                    try {
                        if (_g && !_g.done && (_b = _f.return)) _b.call(_f);
                    }
                    finally { if (e_2) throw e_2.error; }
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (_e && !_e.done && (_a = _d.return)) _a.call(_d);
            }
            finally { if (e_1) throw e_1.error; }
        }
    };
    CommonsKeyboardComponent.prototype.setLabels = function () {
        var e_4, _a;
        var labels = {};
        try {
            for (var _b = __values(Object.keys(this.keyboard.sets)), _c = _b.next(); !_c.done; _c = _b.next()) {
                var setName = _c.value;
                labels[setName] = this.keyboard.sets[setName].label;
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
            }
            finally { if (e_4) throw e_4.error; }
        }
        return labels;
    };
    CommonsKeyboardComponent.prototype.isDisabled = function (key) {
        if (key.ok && this.disableOk)
            return true;
        if (key.backspace && this.disableBackspace)
            return true;
        if (key.cancel && this.disableCancel)
            return true;
        if ((key.character || key.space) && this.disableCharacters)
            return true;
        return false;
    };
    CommonsKeyboardComponent.prototype.doChangeSet = function (set) {
        this.set = set;
    };
    __decorate([
        Input()
    ], CommonsKeyboardComponent.prototype, "keyboard", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardComponent.prototype, "disableOk", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardComponent.prototype, "disableCancel", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardComponent.prototype, "disableBackspace", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardComponent.prototype, "disableCharacters", void 0);
    __decorate([
        Input()
    ], CommonsKeyboardComponent.prototype, "disableThemeInvert", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardComponent.prototype, "onCharacter", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardComponent.prototype, "onOk", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardComponent.prototype, "onCancel", void 0);
    __decorate([
        Output()
    ], CommonsKeyboardComponent.prototype, "onBackspace", void 0);
    CommonsKeyboardComponent = __decorate([
        Component({
            selector: 'commons-keyboard',
            template: "<aside><ul *ngIf=\"this.set\"\n\t\t[class]=\"'columns-' + this.maxColumns\"\n>\n\t<li row *ngFor=\"let row of this.keyboard.sets[this.set].keys\">\n\t\t<ul>\n\t\t\t<li column *ngFor=\"let key of row\"\n\t\t\t\t\t[class.filler]=\"!key\"\n\t\t\t\t\t[class.span-2]=\"key && key.span === 2\"\n\t\t\t\t\t[class.span-3]=\"key && key.span === 3\"\n\t\t\t\t\t[class.span-4]=\"key && key.span === 4\"\n\t\t\t>\n\t\t\t\t<commons-keyboard-key *ngIf=\"key\"\n\t\t\t\t\t\t[key]=\"key\"\n\t\t\t\t\t\t[setLabels]=\"this.setLabels()\"\n\t\t\t\t\t\t[disabled]=\"this.isDisabled(key)\"\n\t\t\t\t\t\t[disableThemeInvert]=\"this.disableThemeInvert\"\n\t\t\t\t\t\t[maxColumns]=\"this.maxColumns\"\n\t\t\t\t\t\t(onCharacter)=\"this.onCharacter.emit($event);\"\n\t\t\t\t\t\t(onSet)=\"this.doChangeSet($event);\"\n\t\t\t\t\t\t(onSpace)=\"this.onCharacter.emit(' ');\"\n\t\t\t\t\t\t(onOk)=\"this.onOk.emit();\"\n\t\t\t\t\t\t(onCancel)=\"this.onCancel.emit();\"\n\t\t\t\t\t\t(onBackspace)=\"this.onBackspace.emit();\"\n\t\t\t\t></commons-keyboard-key>\n\t\t\t</li>\n\t\t</ul>\n\t</li>\n</ul></aside>",
            styles: ["@charset 'utf8';aside{width:100%;display:block}aside>ul{margin:0 auto}aside>ul.columns-0{width:100%;min-width:0;max-width:0}aside>ul.columns-0 li[column]{width:calc(100% / 0);min-width:25px;max-width:60px}aside>ul.columns-0 li[column].span-2{width:calc(200% / 0);min-width:50px;max-width:120px}aside>ul.columns-0 li[column].span-3{width:calc(300% / 0);min-width:75px;max-width:180px}aside>ul.columns-0 li[column].span-4{width:calc(400% / 0);min-width:100px;max-width:240px}aside>ul.columns-1{width:100%;min-width:25px;max-width:60px}aside>ul.columns-1 li[column]{width:calc(100% / 1);min-width:25px;max-width:60px}aside>ul.columns-1 li[column].span-2{width:calc(200% / 1);min-width:50px;max-width:120px}aside>ul.columns-1 li[column].span-3{width:calc(300% / 1);min-width:75px;max-width:180px}aside>ul.columns-1 li[column].span-4{width:calc(400% / 1);min-width:100px;max-width:240px}aside>ul.columns-2{width:100%;min-width:50px;max-width:120px}aside>ul.columns-2 li[column]{width:calc(100% / 2);min-width:25px;max-width:60px}aside>ul.columns-2 li[column].span-2{width:calc(200% / 2);min-width:50px;max-width:120px}aside>ul.columns-2 li[column].span-3{width:calc(300% / 2);min-width:75px;max-width:180px}aside>ul.columns-2 li[column].span-4{width:calc(400% / 2);min-width:100px;max-width:240px}aside>ul.columns-3{width:100%;min-width:75px;max-width:180px}aside>ul.columns-3 li[column]{width:calc(100% / 3);min-width:25px;max-width:60px}aside>ul.columns-3 li[column].span-2{width:calc(200% / 3);min-width:50px;max-width:120px}aside>ul.columns-3 li[column].span-3{width:calc(300% / 3);min-width:75px;max-width:180px}aside>ul.columns-3 li[column].span-4{width:calc(400% / 3);min-width:100px;max-width:240px}aside>ul.columns-4{width:100%;min-width:100px;max-width:240px}aside>ul.columns-4 li[column]{width:calc(100% / 4);min-width:25px;max-width:60px}aside>ul.columns-4 li[column].span-2{width:calc(200% / 4);min-width:50px;max-width:120px}aside>ul.columns-4 li[column].span-3{width:calc(300% / 4);min-width:75px;max-width:180px}aside>ul.columns-4 li[column].span-4{width:calc(400% / 4);min-width:100px;max-width:240px}aside>ul.columns-5{width:100%;min-width:125px;max-width:300px}aside>ul.columns-5 li[column]{width:calc(100% / 5);min-width:25px;max-width:60px}aside>ul.columns-5 li[column].span-2{width:calc(200% / 5);min-width:50px;max-width:120px}aside>ul.columns-5 li[column].span-3{width:calc(300% / 5);min-width:75px;max-width:180px}aside>ul.columns-5 li[column].span-4{width:calc(400% / 5);min-width:100px;max-width:240px}aside>ul.columns-6{width:100%;min-width:150px;max-width:360px}aside>ul.columns-6 li[column]{width:calc(100% / 6);min-width:25px;max-width:60px}aside>ul.columns-6 li[column].span-2{width:calc(200% / 6);min-width:50px;max-width:120px}aside>ul.columns-6 li[column].span-3{width:calc(300% / 6);min-width:75px;max-width:180px}aside>ul.columns-6 li[column].span-4{width:calc(400% / 6);min-width:100px;max-width:240px}aside>ul.columns-7{width:100%;min-width:175px;max-width:420px}aside>ul.columns-7 li[column]{width:calc(100% / 7);min-width:25px;max-width:60px}aside>ul.columns-7 li[column].span-2{width:calc(200% / 7);min-width:50px;max-width:120px}aside>ul.columns-7 li[column].span-3{width:calc(300% / 7);min-width:75px;max-width:180px}aside>ul.columns-7 li[column].span-4{width:calc(400% / 7);min-width:100px;max-width:240px}aside>ul.columns-8{width:100%;min-width:200px;max-width:480px}aside>ul.columns-8 li[column]{width:calc(100% / 8);min-width:25px;max-width:60px}aside>ul.columns-8 li[column].span-2{width:calc(200% / 8);min-width:50px;max-width:120px}aside>ul.columns-8 li[column].span-3{width:calc(300% / 8);min-width:75px;max-width:180px}aside>ul.columns-8 li[column].span-4{width:calc(400% / 8);min-width:100px;max-width:240px}aside>ul.columns-9{width:100%;min-width:225px;max-width:540px}aside>ul.columns-9 li[column]{width:calc(100% / 9);min-width:25px;max-width:60px}aside>ul.columns-9 li[column].span-2{width:calc(200% / 9);min-width:50px;max-width:120px}aside>ul.columns-9 li[column].span-3{width:calc(300% / 9);min-width:75px;max-width:180px}aside>ul.columns-9 li[column].span-4{width:calc(400% / 9);min-width:100px;max-width:240px}aside>ul.columns-10{width:100%;min-width:250px;max-width:600px}aside>ul.columns-10 li[column]{width:calc(100% / 10);min-width:25px;max-width:60px}aside>ul.columns-10 li[column].span-2{width:calc(200% / 10);min-width:50px;max-width:120px}aside>ul.columns-10 li[column].span-3{width:calc(300% / 10);min-width:75px;max-width:180px}aside>ul.columns-10 li[column].span-4{width:calc(400% / 10);min-width:100px;max-width:240px}aside>ul.columns-11{width:100%;min-width:275px;max-width:660px}aside>ul.columns-11 li[column]{width:calc(100% / 11);min-width:25px;max-width:60px}aside>ul.columns-11 li[column].span-2{width:calc(200% / 11);min-width:50px;max-width:120px}aside>ul.columns-11 li[column].span-3{width:calc(300% / 11);min-width:75px;max-width:180px}aside>ul.columns-11 li[column].span-4{width:calc(400% / 11);min-width:100px;max-width:240px}aside>ul.columns-12{width:100%;min-width:300px;max-width:720px}aside>ul.columns-12 li[column]{width:calc(100% / 12);min-width:25px;max-width:60px}aside>ul.columns-12 li[column].span-2{width:calc(200% / 12);min-width:50px;max-width:120px}aside>ul.columns-12 li[column].span-3{width:calc(300% / 12);min-width:75px;max-width:180px}aside>ul.columns-12 li[column].span-4{width:calc(400% / 12);min-width:100px;max-width:240px}aside>ul.columns-13{width:100%;min-width:325px;max-width:780px}aside>ul.columns-13 li[column]{width:calc(100% / 13);min-width:25px;max-width:60px}aside>ul.columns-13 li[column].span-2{width:calc(200% / 13);min-width:50px;max-width:120px}aside>ul.columns-13 li[column].span-3{width:calc(300% / 13);min-width:75px;max-width:180px}aside>ul.columns-13 li[column].span-4{width:calc(400% / 13);min-width:100px;max-width:240px}aside>ul.columns-14{width:100%;min-width:350px;max-width:840px}aside>ul.columns-14 li[column]{width:calc(100% / 14);min-width:25px;max-width:60px}aside>ul.columns-14 li[column].span-2{width:calc(200% / 14);min-width:50px;max-width:120px}aside>ul.columns-14 li[column].span-3{width:calc(300% / 14);min-width:75px;max-width:180px}aside>ul.columns-14 li[column].span-4{width:calc(400% / 14);min-width:100px;max-width:240px}aside>ul.columns-15{width:100%;min-width:375px;max-width:900px}aside>ul.columns-15 li[column]{width:calc(100% / 15);min-width:25px;max-width:60px}aside>ul.columns-15 li[column].span-2{width:calc(200% / 15);min-width:50px;max-width:120px}aside>ul.columns-15 li[column].span-3{width:calc(300% / 15);min-width:75px;max-width:180px}aside>ul.columns-15 li[column].span-4{width:calc(400% / 15);min-width:100px;max-width:240px}aside>ul.columns-16{width:100%;min-width:400px;max-width:960px}aside>ul.columns-16 li[column]{width:calc(100% / 16);min-width:25px;max-width:60px}aside>ul.columns-16 li[column].span-2{width:calc(200% / 16);min-width:50px;max-width:120px}aside>ul.columns-16 li[column].span-3{width:calc(300% / 16);min-width:75px;max-width:180px}aside>ul.columns-16 li[column].span-4{width:calc(400% / 16);min-width:100px;max-width:240px}aside>ul.columns-17{width:100%;min-width:425px;max-width:1020px}aside>ul.columns-17 li[column]{width:calc(100% / 17);min-width:25px;max-width:60px}aside>ul.columns-17 li[column].span-2{width:calc(200% / 17);min-width:50px;max-width:120px}aside>ul.columns-17 li[column].span-3{width:calc(300% / 17);min-width:75px;max-width:180px}aside>ul.columns-17 li[column].span-4{width:calc(400% / 17);min-width:100px;max-width:240px}aside>ul.columns-18{width:100%;min-width:450px;max-width:1080px}aside>ul.columns-18 li[column]{width:calc(100% / 18);min-width:25px;max-width:60px}aside>ul.columns-18 li[column].span-2{width:calc(200% / 18);min-width:50px;max-width:120px}aside>ul.columns-18 li[column].span-3{width:calc(300% / 18);min-width:75px;max-width:180px}aside>ul.columns-18 li[column].span-4{width:calc(400% / 18);min-width:100px;max-width:240px}aside>ul.columns-19{width:100%;min-width:475px;max-width:1140px}aside>ul.columns-19 li[column]{width:calc(100% / 19);min-width:25px;max-width:60px}aside>ul.columns-19 li[column].span-2{width:calc(200% / 19);min-width:50px;max-width:120px}aside>ul.columns-19 li[column].span-3{width:calc(300% / 19);min-width:75px;max-width:180px}aside>ul.columns-19 li[column].span-4{width:calc(400% / 19);min-width:100px;max-width:240px}aside>ul.columns-20{width:100%;min-width:500px;max-width:1200px}aside>ul.columns-20 li[column]{width:calc(100% / 20);min-width:25px;max-width:60px}aside>ul.columns-20 li[column].span-2{width:calc(200% / 20);min-width:50px;max-width:120px}aside>ul.columns-20 li[column].span-3{width:calc(300% / 20);min-width:75px;max-width:180px}aside>ul.columns-20 li[column].span-4{width:calc(400% / 20);min-width:100px;max-width:240px}ul{list-style:none;margin:0;padding:0}ul li[row]{clear:both;width:100%;height:43px}ul li[column]{float:left}ul li[column].filler{height:43px}"]
        })
    ], CommonsKeyboardComponent);
    return CommonsKeyboardComponent;
}(CommonsComponent));

var CommonsEditorDisplayComponent = /** @class */ (function (_super) {
    __extends(CommonsEditorDisplayComponent, _super);
    function CommonsEditorDisplayComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.onMove = new EventEmitter(true);
        _this.preCharacters = [];
        _this.postCharacters = [];
        return _this;
    }
    CommonsEditorDisplayComponent.prototype.ngOnChanges = function (changes) {
        if (changes.pre !== undefined)
            this.preCharacters = changes.pre.currentValue.split('');
        if (changes.post !== undefined)
            this.postCharacters = changes.post.currentValue.split('');
    };
    CommonsEditorDisplayComponent.prototype.movePre = function (index, event) {
        event.stopPropagation();
        this.onMove.emit(index);
    };
    CommonsEditorDisplayComponent.prototype.movePost = function (index, event) {
        event.stopPropagation();
        this.onMove.emit(this.preCharacters.length + index);
    };
    CommonsEditorDisplayComponent.prototype.moveEnd = function () {
        this.onMove.emit(-1);
    };
    __decorate([
        Input()
    ], CommonsEditorDisplayComponent.prototype, "pre", void 0);
    __decorate([
        Input()
    ], CommonsEditorDisplayComponent.prototype, "post", void 0);
    __decorate([
        Output()
    ], CommonsEditorDisplayComponent.prototype, "onMove", void 0);
    CommonsEditorDisplayComponent = __decorate([
        Component({
            selector: 'commons-editor-display',
            template: "<section\n\t\t(click)=\"this.moveEnd();\"\n><span class=\"pre\"><span *ngFor=\"let c of this.preCharacters; let i = index\"\n\t\t(click)=\"this.movePre(i, $event);\"\n>{{c}}</span></span><span class=\"post\"><span *ngFor=\"let c of this.postCharacters; let i = index\"\n\t\t(click)=\"this.movePost(i, $event);\"\n>{{c}}</span></span></section>",
            styles: ["@charset 'utf8';section{font-family:Roboto;font-weight:400;font-size:16px;line-height:16px;white-space:pre;margin:0;height:46px;box-sizing:border-box;padding:15px 10px}:host-context(body.webappcommons-theme-blue) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-blue) section>span.pre{border-right:2px solid #ffc107;margin-right:-2px}:host-context(body.webappcommons-theme-blue) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-darkred) section{background-color:#212121;color:#b8b8b8}:host-context(body.webappcommons-theme-darkred) section>span.pre{border-right:2px solid #ffeb3b;margin-right:-2px}:host-context(body.webappcommons-theme-darkred) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-hotpink) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-hotpink) section>span.pre{border-right:2px solid #9debef;margin-right:-2px}:host-context(body.webappcommons-theme-hotpink) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-marine) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-marine) section>span.pre{border-right:2px solid #99d1dd;margin-right:-2px}:host-context(body.webappcommons-theme-marine) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-muted) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-muted) section>span.pre{border-right:2px solid #fdd835;margin-right:-2px}:host-context(body.webappcommons-theme-muted) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-night) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-night) section>span.pre{border-right:2px solid #e7c385;margin-right:-2px}:host-context(body.webappcommons-theme-night) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-patrolred) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-patrolred) section>span.pre{border-right:2px solid #90a4ae;margin-right:-2px}:host-context(body.webappcommons-theme-patrolred) section>span>span{padding-left:1px}:host-context(body.webappcommons-theme-purple) section{background-color:#fff;color:#333}:host-context(body.webappcommons-theme-purple) section>span.pre{border-right:2px solid #fc3;margin-right:-2px}:host-context(body.webappcommons-theme-purple) section>span>span{padding-left:1px}"]
        })
    ], CommonsEditorDisplayComponent);
    return CommonsEditorDisplayComponent;
}(CommonsComponent));

var CommonsEditorComponent = /** @class */ (function (_super) {
    __extends(CommonsEditorComponent, _super);
    function CommonsEditorComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.value = '';
        _this.allowEmpty = false;
        _this.maxLength = 255;
        _this.minLength = 0;
        _this.onCancel = new EventEmitter(true);
        _this.onOk = new EventEmitter(true);
        _this.characters = [];
        _this.position = 0;
        _this.pre = '';
        _this.post = '';
        return _this;
    }
    CommonsEditorComponent.prototype.ngOnInit = function () {
        _super.prototype.ngOnInit.call(this);
        this.characters = this.value.split('');
        this.position = this.characters.length;
        this.rebuild();
    };
    CommonsEditorComponent.prototype.ngOnChanges = function () {
        this.characters = this.value.split('');
        this.position = this.characters.length;
        this.rebuild();
    };
    CommonsEditorComponent.prototype.rebuild = function () {
        this.pre = this.characters.slice(0, this.position).join('');
        this.post = this.characters.slice(this.position).join('');
    };
    CommonsEditorComponent.prototype.append = function (character) {
        this.characters.splice(this.position, 0, character);
        this.position++;
        this.rebuild();
    };
    CommonsEditorComponent.prototype.doCharacter = function (character) {
        this.append(character);
    };
    CommonsEditorComponent.prototype.doOk = function () {
        this.onOk.emit(this.pre + this.post);
    };
    CommonsEditorComponent.prototype.doCancel = function () {
        this.onCancel.emit();
    };
    CommonsEditorComponent.prototype.doBackspace = function () {
        if (this.position === 0)
            return;
        this.position--;
        this.characters.splice(this.position, 1);
        this.rebuild();
    };
    CommonsEditorComponent.prototype.doMove = function (index) {
        this.position = index === -1 ? this.characters.length : index;
        this.rebuild();
    };
    __decorate([
        Input()
    ], CommonsEditorComponent.prototype, "value", void 0);
    __decorate([
        Input()
    ], CommonsEditorComponent.prototype, "allowEmpty", void 0);
    __decorate([
        Input()
    ], CommonsEditorComponent.prototype, "maxLength", void 0);
    __decorate([
        Input()
    ], CommonsEditorComponent.prototype, "minLength", void 0);
    __decorate([
        Input()
    ], CommonsEditorComponent.prototype, "keyboard", void 0);
    __decorate([
        Output()
    ], CommonsEditorComponent.prototype, "onCancel", void 0);
    __decorate([
        Output()
    ], CommonsEditorComponent.prototype, "onOk", void 0);
    CommonsEditorComponent = __decorate([
        Component({
            selector: 'commons-editor',
            template: "<aside>\n\t<commons-editor-display\n\t\t\t[pre]=\"this.pre\"\n\t\t\t[post]=\"this.post\"\n\t\t\t(onMove)=\"this.doMove($event);\"\n\t></commons-editor-display>\n\t<commons-keyboard\n\t\t\t[keyboard]=\"this.keyboard\"\n\t\t\t[disableOk]=\"!this.allowEmpty && this.characters.length < this.minLength\"\n\t\t\t[disableBackspace]=\"!this.characters.length\"\n\t\t\t[disableCharacters]=\"this.characters.length >= this.maxLength\"\n\t\t\t(onCharacter)=\"this.doCharacter($event);\"\n\t\t\t(onOk)=\"this.doOk();\"\n\t\t\t(onCancel)=\"this.doCancel();\"\n\t\t\t(onBackspace)=\"this.doBackspace();\"\n\t></commons-keyboard>\n</aside>\n",
            styles: ["@charset 'utf8';aside{display:block}:host-context(body.webappcommons-theme-blue) aside{background-color:#f2f2f2}:host-context(body.webappcommons-theme-darkred) aside{background-color:#2a2a2a}:host-context(body.webappcommons-theme-hotpink) aside{background-color:#f2f2f2}:host-context(body.webappcommons-theme-marine) aside{background-color:#f2f2f2}:host-context(body.webappcommons-theme-muted) aside{background-color:#f2f2f2}:host-context(body.webappcommons-theme-night) aside{background-color:#f2f2f2}:host-context(body.webappcommons-theme-patrolred) aside{background-color:#f2f2f2}:host-context(body.webappcommons-theme-purple) aside{background-color:#f2f2f2}"]
        })
    ], CommonsEditorComponent);
    return CommonsEditorComponent;
}(CommonsComponent));

var CommonsDrawerEditorComponent = /** @class */ (function (_super) {
    __extends(CommonsDrawerEditorComponent, _super);
    function CommonsDrawerEditorComponent(editorService) {
        var _this = _super.call(this) || this;
        _this.editorService = editorService;
        _this.ECommonsDrawerDirection = ECommonsDrawerDirection;
        _this.show = false;
        _this.value = '';
        _this.allowEmpty = false;
        _this.maxLength = 255;
        _this.minLength = 0;
        _this.keyboard = undefined;
        // these are simply placeholders that are replaced by the subscription data, so for now don't do anything
        _this.ok = function (_) {
            // do nothing
        };
        _this.cancel = function () {
            // do nothing
        };
        return _this;
    }
    CommonsDrawerEditorComponent.prototype.ngOnInit = function () {
        var _this = this;
        _super.prototype.ngOnInit.call(this);
        this.subscribe(this.editorService.showObservable(), function (data) {
            _this.value = data.value;
            _this.keyboard = data.settings.keyboard;
            _this.allowEmpty = data.settings.allowEmpty || false;
            _this.maxLength = data.settings.maxLength || 255;
            _this.minLength = data.settings.minLength || 0;
            _this.ok = data.ok;
            _this.cancel = data.cancel;
            _this.show = true;
        });
        this.subscribe(this.editorService.hideObservable(), function () {
            _this.show = false;
        });
    };
    CommonsDrawerEditorComponent.prototype.doCancel = function () {
        this.cancel();
    };
    CommonsDrawerEditorComponent.prototype.doOk = function (value) {
        this.ok(value);
    };
    CommonsDrawerEditorComponent.ctorParameters = function () { return [
        { type: CommonsEditorService }
    ]; };
    CommonsDrawerEditorComponent = __decorate([
        Component({
            selector: 'commons-drawer-editor',
            template: "<commons-drawer\n\t\t[name]=\"'_editor'\"\n\t\t[direction]=\"ECommonsDrawerDirection.BOTTOM\"\n>\n\t<section><commons-editor *ngIf=\"this.show\"\n\t\t\t[keyboard]=\"this.keyboard\"\n\t\t\t[value]=\"this.value\"\n\t\t\t[allowEmpty]=\"this.allowEmpty\"\n\t\t\t[maxLength]=\"this.maxLength\"\n\t\t\t[minLength]=\"this.minLength\"\n\t\t\t(onCancel)=\"this.doCancel();\"\n\t\t\t(onOk)=\"this.doOk($event);\"\n\t></commons-editor></section>\n</commons-drawer>\n",
            styles: ["@charset 'utf8';section{width:100vw}"]
        })
    ], CommonsDrawerEditorComponent);
    return CommonsDrawerEditorComponent;
}(CommonsComponent));

var NgxWebAppCommonsKeyboardModule = /** @class */ (function () {
    function NgxWebAppCommonsKeyboardModule() {
    }
    NgxWebAppCommonsKeyboardModule_1 = NgxWebAppCommonsKeyboardModule;
    NgxWebAppCommonsKeyboardModule.forRoot = function () {
        return {
            ngModule: NgxWebAppCommonsKeyboardModule_1,
            providers: [
                CommonsEditorService
            ]
        };
    };
    var NgxWebAppCommonsKeyboardModule_1;
    NgxWebAppCommonsKeyboardModule = NgxWebAppCommonsKeyboardModule_1 = __decorate([
        NgModule({
            imports: [
                CommonModule,
                NgxWebAppCommonsCoreModule,
                NgxWebAppCommonsMobileModule
            ],
            declarations: [
                CommonsKeyboardKeyComponent,
                CommonsKeyboardComponent,
                CommonsEditorComponent,
                CommonsEditorDisplayComponent,
                CommonsDrawerEditorComponent
            ],
            exports: [
                CommonsKeyboardComponent,
                CommonsEditorComponent,
                CommonsDrawerEditorComponent
            ]
        })
    ], NgxWebAppCommonsKeyboardModule);
    return NgxWebAppCommonsKeyboardModule;
}());

/*
 * Public API Surface of ngx-webappcommons-keyboard
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CommonsDrawerEditorComponent, CommonsEditorComponent, CommonsEditorDisplayComponent, CommonsEditorService, CommonsKeyboardComponent, CommonsKeyboardKeyComponent, FULL_KEYBOARD, LOGIN_PIN_KEYBOARD, NgxWebAppCommonsKeyboardModule, SIMPLE_KEYBOARD };
//# sourceMappingURL=ngx-webappcommons-keyboard.js.map
